@@ -255,7 +255,7 @@ for(i=0;i<len;i++)
 	}
 if(i==len)
 	{
-	int shmid;
+	unsigned int shmid;
 	
 	sscanf(id, "%x", &shmid);
 #ifdef __MINGW32__
@@ -530,8 +530,11 @@ return(0);
 }
 
 /*
- * $Id: stem_recurse.c,v 1.7 2009/06/13 22:02:18 gtkwave Exp $
+ * $Id: stem_recurse.c,v 1.8 2010/07/16 16:12:36 gtkwave Exp $
  * $Log: stem_recurse.c,v $
+ * Revision 1.8  2010/07/16 16:12:36  gtkwave
+ * pedantic warning fixes
+ *
  * Revision 1.7  2009/06/13 22:02:18  gtkwave
  * beginning to add FST support to rtlbrowse
  *
