@@ -8,9 +8,11 @@
 #include "../../src/debug.h"
 #include "../../src/helpers/vzt_read.h"
 #include "../../src/helpers/lxt2_read.h"
+#include <fstapi.h>
 
 extern struct vzt_rd_trace  *vzt;
 extern struct lxt2_rd_trace *lx2;
+extern void *fst;
 
 #ifdef AET2_IS_PRESENT
 extern AE2_HANDLE ae2;
@@ -19,8 +21,11 @@ extern AE2_HANDLE ae2;
 #endif
 
 /*
- * $Id: wavelink.h,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
+ * $Id: wavelink.h,v 1.3 2009/06/13 22:02:18 gtkwave Exp $
  * $Log: wavelink.h,v $
+ * Revision 1.3  2009/06/13 22:02:18  gtkwave
+ * beginning to add FST support to rtlbrowse
+ *
  * Revision 1.2  2007/08/26 21:35:39  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
