@@ -256,12 +256,12 @@ return(cpylen);
  */
 int mgetchar2(void)
 {
-unsigned char buf[2];
+unsigned char cbuf[2];
 
 if(preproc_buff_head)
 	{
-	mgetstr((char *)buf, 1);
-	return(buf[0]);
+	mgetstr((char *)cbuf, 1);
+	return(cbuf[0]);
 	}
 
 if(fh)
@@ -635,6 +635,14 @@ if(s2)
 
 		warn("** Warning: malformed `define directive in file '%s' line %d missing endquote, added.\n", zzfilename, zzline);
 		}
+
+	len = strlen(s2);
+	pnt = s2+len;
+	while(pnt != s2)
+		{
+		pnt--;
+		if(isspace(*pnt)) { *pnt = 0; } else { break; }
+		}
 	}
 
 add_define_to_tree(define_tree, s1, s2);
@@ -984,8 +992,14 @@ if(ics)
 }
 
 /*
- * $Id: preproc.c,v 1.1.1.1 2007/05/30 04:25:46 gtkwave Exp $
+ * $Id: preproc.c,v 1.3 2008/12/20 05:45:03 gtkwave Exp $
  * $Log: preproc.c,v $
+ * Revision 1.3  2008/12/20 05:45:03  gtkwave
+ * gtk1 compatibility and -Wshadow warning fixes
+ *
+ * Revision 1.2  2008/11/11 15:30:26  gtkwave
+ * carriage return in defines fix
+ *
  * Revision 1.1.1.1  2007/05/30 04:25:46  gtkwave
  * Imported sources
  *
