@@ -684,7 +684,25 @@ void RemoveTrace( Trptr t, int dofree )
       }
     else
       {
-        t->t_prev->t_next = t->t_next;
+        if(t->t_prev)
+		{
+	        t->t_prev->t_next = t->t_next;
+		}
+		else
+		{
+		/* this code should likely *never* execute as if( t == GLOBALS->traces.first ) above should catch this */
+		/* there is likely a problem elsewhere in the code! */
+
+		Trptr t2 = GLOBALS->traces.first = t->t_next;
+		GLOBALS->traces.total = 0;
+		while(t2)
+			{
+			t2 = t2->t_next;
+			GLOBALS->traces.total++;
+			}
+		}
+
+
         if( t->t_next )
             t->t_next->t_prev = t->t_prev;
         else
@@ -799,6 +817,7 @@ Trptr PasteBuffer(void)
       while(t)
 	{
           t->t_prev = prev; /* defensive re-link move */
+	  prev = t;
 	  GLOBALS->traces.last=t;
 	  GLOBALS->traces.total++;
 	  t=t->t_next;
@@ -1493,8 +1512,14 @@ if((underflow_sticky) || (oc_cnt > 0))
 }
 
 /*
- * $Id: analyzer.c,v 1.27 2010/06/23 05:45:34 gtkwave Exp $
+ * $Id: analyzer.c,v 1.29 2010/07/06 16:06:09 gtkwave Exp $
  * $Log: analyzer.c,v $
+ * Revision 1.29  2010/07/06 16:06:09  gtkwave
+ * defensive re-link fix in PasteBuffer
+ *
+ * Revision 1.28  2010/07/01 17:58:23  gtkwave
+ * Segmentation fault on signal reordering - ID: 3023401
+ *
  * Revision 1.27  2010/06/23 05:45:34  gtkwave
  * warnings fixes
  *
