@@ -27,6 +27,8 @@ typedef struct _SearchProgressData {
 } SearchProgressData;
 
 
+#define BITATTRIBUTES_MAX 32768
+
 typedef struct ExpandInfo *eptr;
 typedef struct ExpandReferences *exptr;
 typedef struct Node	  *nptr;
@@ -233,7 +235,7 @@ typedef struct BitAttributes
 typedef struct Bits
   {
     char    *name;		/* name of this vector of bits   */
-    int     nbits;		/* number of bits in this vector */
+    int     nnbits;		/* number of bits in this vector */
     baptr attribs;  		/* for keeping track of combined timeshifts and inversions (and for savefile) */
     
     nptr    nodes[1];		/* pointers to the bits (nodes)  */
@@ -241,7 +243,10 @@ typedef struct Bits
 
 typedef struct BitVector
   {
-    char    *name;		/* name of this vector of bits           */
+    bvptr   transaction_cache;  /* for TR_TTRANSLATED traces */
+    bvptr   transaction_chain;	/* for TR_TTRANSLATED traces */
+
+    char    *bvname;		/* name of this vector of bits           */
     int     nbits;		/* number of bits in this vector         */
     int     numregions;		/* number of regions that follow         */
     bptr    bits;		/* pointer to Bits structs for save file */
@@ -304,10 +309,20 @@ typedef struct TraceEnt
     TimeType shift;		/* offset added to all entries in the trace */
     TimeType shift_drag;	/* cached initial offset for CTRL+LMB drag on highlighted */
 
+    double   d_minval, d_maxval; /* cached value for when auto scaling is turned off */
+
+    union
+      {
+	nptr    nd;		/* what makes up this trace */
+	bvptr   vec;
+      } n;
+
+    unsigned int flags;		/* see def below in TraceEntFlagBits */
+    unsigned int cached_flags;	/* used for tcl for saving flags during cut and paste */
+
     int	     f_filter;		/* file filter */
     int	     p_filter;		/* process filter */
-
-    double   d_minval, d_maxval; /* cached value for when auto scaling is turned off */
+    int	     t_filter;		/* transaction process filter */
 
     unsigned is_alias : 1;	/* set when it's an alias (safe to free t->name then) */
     unsigned is_depacked : 1;	/* set when it's been depacked from a compressed entry (safe to free t->name then) */
@@ -316,15 +331,7 @@ typedef struct TraceEnt
     unsigned interactive_vector_needs_regeneration : 1; /* for interactive VCDs */
     unsigned minmax_valid : 1;	/* for d_minval, d_maxval */
     unsigned is_sort_group : 1; /* only used for sorting purposes */
-
-    unsigned int flags;		/* see def below in TraceEntFlagBits */
-    unsigned int cached_flags;	/* used for tcl for saving flags during cut and paste */
-
-    union
-      {
-	nptr    nd;		/* what makes up this trace */
-	bvptr   vec;
-      } n;
+    unsigned t_filter_converted : 1; /* used to mark that data conversion already occurred if t_filter != 0*/
   } TraceEnt;
 
 
@@ -336,7 +343,8 @@ enum TraceEntFlagBits
   TR_ANALOG_INTERPOLATED_B, TR_ANALOG_BLANK_STRETCH_B, TR_REAL_B, TR_ANALOG_FULLSCALE_B, 
   TR_ZEROFILL_B, TR_ONEFILL_B, TR_CLOSED_B, TR_GRP_BEGIN_B, 
   TR_GRP_END_B,
-  TR_BINGRAY_B, TR_GRAYBIN_B
+  TR_BINGRAY_B, TR_GRAYBIN_B,
+  TR_REAL2BITS_B, TR_TTRANSLATED_B
 };
  
 #define TR_HIGHLIGHT 		(1<<TR_HIGHLIGHT_B)
@@ -368,6 +376,8 @@ enum TraceEntFlagBits
 #define TR_GRAYBIN		(1<<TR_GRAYBIN_B)
 #define TR_GRAYMASK		(TR_BINGRAY|TR_GRAYBIN)
 
+#define TR_REAL2BITS            (1<<TR_REAL2BITS_B)
+
 #define TR_NUMMASK	(TR_ASCII|TR_HEX|TR_DEC|TR_BIN|TR_OCT|TR_SIGNED|TR_REAL)
 
 #define TR_COLLAPSED	(1<<TR_COLLAPSED_B)
@@ -375,6 +385,7 @@ enum TraceEntFlagBits
 
 #define TR_FTRANSLATED	(1<<TR_FTRANSLATED_B)
 #define TR_PTRANSLATED	(1<<TR_PTRANSLATED_B)
+#define TR_TTRANSLATED  (1<<TR_TTRANSLATED_B)
 
 #define TR_ANALOGMASK	(TR_ANALOG_STEP|TR_ANALOG_INTERPOLATED)
 
@@ -436,8 +447,20 @@ void ClearGroupTraces(Trptr t);
 #endif
 
 /*
- * $Id: analyzer.h,v 1.24 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: analyzer.h,v 1.28 2010/04/07 01:50:45 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.28  2010/04/07 01:50:45  gtkwave
+ * improved name handling for bvname, add $next transaction operation
+ *
+ * Revision 1.27  2010/04/04 19:09:57  gtkwave
+ * rename name->bvname in struct BitVector for easier grep tracking
+ *
+ * Revision 1.26  2010/03/31 15:42:47  gtkwave
+ * added preliminary transaction filter support
+ *
+ * Revision 1.25  2010/03/24 23:05:09  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.24  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
