@@ -1397,7 +1397,7 @@ if(!t->t_filter_converted)
 	}
 	else
 	{
-	s = strdup_2(v->v);
+	s = strdup_2((char *)v->v);
 
 	if((*s == '?') && (!GLOBALS->color_active_in_filter))
 	        {  
@@ -1718,8 +1718,11 @@ return(retval);
 }
 
 /*
- * $Id: baseconvert.c,v 1.16 2010/03/31 16:32:20 gtkwave Exp $
+ * $Id: baseconvert.c,v 1.17 2010/06/23 05:45:34 gtkwave Exp $
  * $Log: baseconvert.c,v $
+ * Revision 1.17  2010/06/23 05:45:34  gtkwave
+ * warnings fixes
+ *
  * Revision 1.16  2010/03/31 16:32:20  gtkwave
  * stale marker fix for ttranslate on save file loads before GUI initialized
  *
