@@ -519,6 +519,20 @@ if(!GLOBALS->use_maxtime_display)
 
 	gtk_label_set(GTK_LABEL(GLOBALS->maxtimewid_currenttime_c_1), GLOBALS->maxtext_currenttime_c_1);
 	}
+
+if(GLOBALS->named_marker_lock_idx>-1)
+	{
+	if(GLOBALS->tims.marker >= 0)
+		{
+		int ent_idx = GLOBALS->named_marker_lock_idx;
+
+		if(GLOBALS->named_markers[ent_idx] != GLOBALS->tims.marker)
+			{
+			GLOBALS->named_markers[ent_idx] = GLOBALS->tims.marker;
+			wavearea_configure_event(GLOBALS->wavearea, NULL);
+			}
+		}
+	}
 }
 
 
@@ -733,8 +747,11 @@ switch(scale)
 }
 
 /*
- * $Id: currenttime.c,v 1.14 2009/09/08 15:31:48 gtkwave Exp $
+ * $Id: currenttime.c,v 1.15 2010/01/18 20:47:02 gtkwave Exp $
  * $Log: currenttime.c,v $
+ * Revision 1.15  2010/01/18 20:47:02  gtkwave
+ * added named locker marking
+ *
  * Revision 1.14  2009/09/08 15:31:48  gtkwave
  * handle floating-point numbers in unformat_time()
  *
