@@ -29,9 +29,9 @@ Pvoid_t  PJArray = (Pvoid_t)GLOBALS->alloc2_chain;
 int rcValue;
 Word_t Index;
 JError_t JError;
+#ifdef DEBUG_PRINTF
 int ctr = 0;
 
-#ifdef DEBUG_PRINTF
 printf("\n*** cleanup ***\n");
 printf("Freeing %d chunks\n", GLOBALS->outstanding);
 system("date");
@@ -46,7 +46,9 @@ Index = 0;
 for (rcValue = Judy1First(PJArray, &Index, &JError); rcValue != 0; rcValue = Judy1Next(PJArray, &Index, &JError))
 	{
 	free((void *)Index);
+#ifdef DEBUG_PRINTF
 	ctr++;
+#endif
 	}
 Judy1FreeArray(&PJArray, &JError);
 
@@ -486,8 +488,11 @@ return(tmpspace);
 }
 
 /*
- * $Id: debug.c,v 1.13 2010/03/16 21:01:08 gtkwave Exp $
+ * $Id: debug.c,v 1.14 2010/05/01 19:20:56 gtkwave Exp $
  * $Log: debug.c,v $
+ * Revision 1.14  2010/05/01 19:20:56  gtkwave
+ * cppcheck warnings fixes
+ *
  * Revision 1.13  2010/03/16 21:01:08  gtkwave
  * remove selected member of struct symbol
  *
