@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2004.
+ * Copyright (c) Tony Bybell 1999-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,13 +25,6 @@
 
 #define WAVE_MAX_CLIST_LENGTH 15000
 
-struct memchunk
-{
-struct memchunk *next;
-void *ptr;
-size_t size;
-};
-
 
 /*
  * If you have problems viewing traces (mangled timevalues),
@@ -200,8 +193,14 @@ unsigned viewer_is_initialized : 1;
 #endif
 
 /*
- * $Id: debug.h,v 1.10 2009/10/08 15:32:53 gtkwave Exp $
+ * $Id: debug.h,v 1.12 2010/03/09 22:21:29 gtkwave Exp $
  * $Log: debug.h,v $
+ * Revision 1.12  2010/03/09 22:21:29  gtkwave
+ * added optional preliminary Judy array support
+ *
+ * Revision 1.11  2010/01/26 23:08:01  gtkwave
+ * removed unused obsolete structure definition
+ *
  * Revision 1.10  2009/10/08 15:32:53  gtkwave
  * remove all instances of "long long"
  *
