@@ -36,7 +36,7 @@ const char *extload_loader_fail_msg = "Sorry, EXTLOAD support was not compiled i
 
 TimeType extload_main(char *fname, char *skip_start, char *skip_end)
 {
-fprintf(stderr, extload_loader_fail_msg);
+fprintf(stderr, "%s", extload_loader_fail_msg);
 exit(255);
 
 return(0); /* for vc++ */
@@ -44,7 +44,7 @@ return(0); /* for vc++ */
 
 void import_extload_trace(nptr np)
 {
-fprintf(stderr, extload_loader_fail_msg);
+fprintf(stderr, "%s", extload_loader_fail_msg);
 exit(255);
 }
 
@@ -1005,8 +1005,11 @@ if(nold!=np)
 #endif
 
 /*
- * $Id: extload.c,v 1.10 2010/03/19 17:50:57 gtkwave Exp $
+ * $Id: extload.c,v 1.11 2010/05/27 06:56:39 gtkwave Exp $
  * $Log: extload.c,v $
+ * Revision 1.11  2010/05/27 06:56:39  gtkwave
+ * printf warning fixes
+ *
  * Revision 1.10  2010/03/19 17:50:57  gtkwave
  * compatibility fixes from fac struct changes
  *
