@@ -269,16 +269,21 @@ recurse_tree_build_whichcache(GLOBALS->treeroot);
 
 for(i=0;i<GLOBALS->numfacs;i++)
         {
-        char *subst, ch;
+        char *subst;
+#ifdef WAVE_HIERFIX
+        char ch;
+#endif
         int len;
         struct symbol *curnode = GLOBALS->facs[i];
 
         if((len=strlen(subst=curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+#ifdef WAVE_HIERFIX
         while((ch=(*subst)))
                 { 
                 if(ch==GLOBALS->hier_delimeter) { *subst=VCDNAM_HIERSORT; } /* forces sort at hier boundaries */
                 subst++;
                 }
+#endif
         }
 
 wave_heapsort(GLOBALS->facs,GLOBALS->numfacs);
@@ -298,6 +303,7 @@ if(GLOBALS->gwt_corr_ghw_c_1)
 	incinerate_whichcache_tree(GLOBALS->gwt_corr_ghw_c_1); GLOBALS->gwt_corr_ghw_c_1 = NULL;
 	}
  
+#ifdef WAVE_HIERFIX
 for(i=0;i<GLOBALS->numfacs;i++)
         {
         char *subst, ch;
@@ -309,6 +315,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
                 subst++;
                 }
         }
+#endif
 
 GLOBALS->facs_are_sorted=1;
 }
@@ -433,14 +440,18 @@ build_hierarchy_type (struct ghw_handler *h, union ghw_type *t,
     case ghdl_rtik_type_p64:
 
       s = calloc_2(1, sizeof(struct symbol));
-      if(!GLOBALS->sym_head_ghw_c_1)
-		{
-		GLOBALS->sym_head_ghw_c_1 = GLOBALS->sym_curr_ghw_c_1 = s;
-		}
-		else
-		{
-		GLOBALS->sym_curr_ghw_c_1->next = s; GLOBALS->sym_curr_ghw_c_1 = s;
-		}
+
+        if(!GLOBALS->firstnode)
+                {                                
+                GLOBALS->firstnode=
+                GLOBALS->curnode=calloc_2(1, sizeof(struct symchain)); 
+                }                                
+                else
+                {                                
+                GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain)); 
+                GLOBALS->curnode=GLOBALS->curnode->next; 
+                }                                
+        GLOBALS->curnode->symbol=s;
 
       GLOBALS->nbr_sig_ref_ghw_c_1++;
       res = (struct tree *) calloc_2(1, sizeof (struct tree) + strlen(pfx));
@@ -630,8 +641,8 @@ facs_debug (void)
 
       n = GLOBALS->facs[i]->n;
       printf ("%d: %s\n", i, n->nname);
-      if (n->ext)
-	printf ("  ext: %d - %d\n", n->ext->msi, n->ext->lsi);
+      if (n->extvals)
+	printf ("  ext: %d - %d\n", n->msi, n->lsi);
       for (h = &n->head; h; h = h->next)
 	printf ("  time:"GHWLLD" flags:%02x vect:%p\n",
 		h->time, h->flags, h->v.h_vector);
@@ -643,16 +654,16 @@ static void
 create_facs (struct ghw_handler *h)
 {
   int i;
-  struct symbol *s = GLOBALS->sym_head_ghw_c_1;
+  struct symchain *sc = GLOBALS->firstnode;
 
   GLOBALS->numfacs = GLOBALS->nbr_sig_ref_ghw_c_1;
   GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 
   i = 0;
-  while(s)
+  while(sc)
 	{
-	GLOBALS->facs[i++] = s;
-	s = s->next;
+	GLOBALS->facs[i++] = sc->symbol;
+	sc = sc->next;
 	}
 
   for (i = 0; i < h->nbr_sigs; i++)
@@ -665,14 +676,14 @@ create_facs (struct ghw_handler *h)
 	  case ghdl_rtik_type_b2:
 	    if (h->sigs[i].type->en.wkt == ghw_wkt_bit)
 	      {
-		n->ext = NULL;
+		n->extvals = 0;
 		break;
 	      }
 	    /* FALLTHROUGH */
 	  case ghdl_rtik_type_e8:
 	    if (GLOBALS->xlat_1164_ghw_c_1 && h->sigs[i].type->en.wkt == ghw_wkt_std_ulogic)
 	      {
-		n->ext = NULL;
+		n->extvals = 0;
 		break;
 	      }
 	    /* FALLTHROUGH */
@@ -682,12 +693,13 @@ create_facs (struct ghw_handler *h)
 	  case ghdl_rtik_type_f64:
 	  case ghdl_rtik_type_p32:
 	  case ghdl_rtik_type_p64:
-	    n->ext = &GLOBALS->dummy_en_ghw_c_1;
+	    n->extvals = 1;
+	    n->msi = n->lsi = 0;
 	    break;
 	  default:
 	    fprintf (stderr, "ghw:create_facs: unhandled kind %d\n",
 		     h->sigs[i].type->kind);
-	    n->ext = NULL;
+	    n->extvals = 0;
 	  }
     }
 
@@ -732,7 +744,8 @@ set_fac_name_1 (struct tree *t)
 
       if (t->which >= 0)
 	{
-        struct symbol *s = GLOBALS->sym_head_ghw_c_1;
+        struct symchain *sc = GLOBALS->firstnode;
+	struct symbol *s = sc->symbol;
 
 	s->name = strdup_2(GLOBALS->fac_name_ghw_c_1);
 	s->n = GLOBALS->nxp_ghw_c_1[t->which];
@@ -740,7 +753,9 @@ set_fac_name_1 (struct tree *t)
 
 	t->which = GLOBALS->sym_which_ghw_c_1++; /* patch in gtkwave "which" as node is correct */
 
-	GLOBALS->sym_head_ghw_c_1 = GLOBALS->sym_head_ghw_c_1->next;
+	GLOBALS->curnode = GLOBALS->firstnode->next;
+	free_2(GLOBALS->firstnode);
+	GLOBALS->firstnode = GLOBALS->curnode;
 	}
 
       if (t->child)
@@ -1116,8 +1131,20 @@ ghw_main(char *fname)
 /*******************************************************************************/
 
 /*
- * $Id: ghw.c,v 1.10 2010/01/05 06:18:33 gtkwave Exp $
+ * $Id: ghw.c,v 1.14 2010/03/15 01:17:00 gtkwave Exp $
  * $Log: ghw.c,v $
+ * Revision 1.14  2010/03/15 01:17:00  gtkwave
+ * fix abuse of next pointer in ghw symbol creation/traversal
+ *
+ * Revision 1.13  2010/03/14 20:12:28  gtkwave
+ * rename next hash pointer in struct symbol
+ *
+ * Revision 1.12  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.11  2010/01/23 03:21:11  gtkwave
+ * hierarchy fixes when characters < "." are in the signal names
+ *
  * Revision 1.10  2010/01/05 06:18:33  gtkwave
  * emergency fix on missing comment causing bad code
  *
