@@ -25,7 +25,7 @@
 #include <stdlib.h>
 
 
-#if HAVE_INTTYPES_H
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
 #define GHWLLD "%"PRId64
 #define GHWLD  "%"PRId32
@@ -40,7 +40,7 @@
 	#define GHWLD "%d"
 #else
 	#define GHWLLD "%lld"
-	#define GHWLLD "%ld"
+	#define GHWLD "%ld"
 #endif
 #endif
 #endif
@@ -422,8 +422,14 @@ void ghw_disp_types (struct ghw_handler *h);
 #endif /* _GHWLIB_H_ */
 
 /*
- * $Id: ghwlib.h,v 1.5 2009/12/29 07:07:49 gtkwave Exp $
+ * $Id: ghwlib.h,v 1.7 2010/04/27 23:10:56 gtkwave Exp $
  * $Log: ghwlib.h,v $
+ * Revision 1.7  2010/04/27 23:10:56  gtkwave
+ * made inttype.h inclusion conditional
+ *
+ * Revision 1.6  2010/04/25 01:04:21  gtkwave
+ * typo fix
+ *
  * Revision 1.5  2009/12/29 07:07:49  gtkwave
  * fixes for ghw files
  *
