@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-7 Tony Bybell.
+ * Copyright (c) 2003-2009 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -33,6 +33,7 @@ static char *match = NULL;
 static int matchlen = 0;
 static int names_only = 0;
 static char *killed_list = NULL;
+char killed_value = 1;
 
 extern void free_hier(void);
 extern char *output_hier(char *name);
@@ -68,17 +69,17 @@ if(g->len >= matchlen)
 	{
 	if(!killed_list[*pnt_facidx])
 		{
-		if(strstr(*pnt_value, match))
+		if((!match)|| (strstr(*pnt_value, match)))
 			{
 			if(g->len > 1)
 				{
 				if(!names_only)
 					{
-					printf("#"LXT2_RD_LLD" %s[%d:%d] %s\n", *pnt_time, lxt2_rd_get_facname(*lt, *pnt_facidx), g->msb, g->lsb, *pnt_value);
+					printf("#"LXT2_RD_LLD" %s["LXT2_RD_LD":"LXT2_RD_LD"] %s\n", *pnt_time, lxt2_rd_get_facname(*lt, *pnt_facidx), g->msb, g->lsb, *pnt_value);
 					}
 					else
 					{
-					printf("%s[%d:%d]\n", lxt2_rd_get_facname(*lt, *pnt_facidx), g->msb, g->lsb);
+					printf("%s["LXT2_RD_LD":"LXT2_RD_LD"]\n", lxt2_rd_get_facname(*lt, *pnt_facidx), g->msb, g->lsb);
 					}
 				}
 				else
@@ -98,16 +99,19 @@ if(g->len >= matchlen)
 					{
 					if(!names_only)
 						{
-						printf("#"LXT2_RD_LLD" %s[%d] %s\n", *pnt_time, lxt2_rd_get_facname(*lt, *pnt_facidx), g->msb, *pnt_value);
+						printf("#"LXT2_RD_LLD" %s["LXT2_RD_LD"] %s\n", *pnt_time, lxt2_rd_get_facname(*lt, *pnt_facidx), g->msb, *pnt_value);
 						}
 						else
 						{
-						printf("%s[%d]\n", lxt2_rd_get_facname(*lt, *pnt_facidx), g->msb);
+						printf("%s["LXT2_RD_LD"]\n", lxt2_rd_get_facname(*lt, *pnt_facidx), g->msb);
 						}
 					}
 				}
-			lxt2_rd_clr_fac_process_mask(*lt, *pnt_facidx);
-			killed_list[*pnt_facidx] = 1;
+			if(killed_value)
+				{
+				lxt2_rd_clr_fac_process_mask(*lt, *pnt_facidx);
+				killed_list[*pnt_facidx] = 1;
+				}
 			}
 		}
 	}
@@ -153,6 +157,7 @@ printf(
 "  -m, --match                bitwise match value\n"
 "  -x, --hex                  hex match value\n"
 "  -n, --namesonly            emit facsnames only (gtkwave savefile)\n"
+"  -c, --comprehensive        do not stop after first match\n"
 "  -h, --help                 display this help then exit\n\n"
 "First occurrence of facnames with times and matching values are emitted to\nstdout.  Using -n generates a gtkwave save file.\n\n"
 "Report bugs to <bybell@nc.rr.com>.\n",nam);
@@ -163,6 +168,7 @@ printf(
 "  -m                         bitwise match value\n"
 "  -x                         hex match value\n"
 "  -n                         emit facsnames only\n"
+"  -c                         do not stop after first match\n"
 "  -h                         display this help then exit (gtkwave savefile)\n\n"
 "First occurrence of facnames with times and matching values are emitted to\nstdout.  Using -n generates a gtkwave save file.\n\n"
 "Report bugs to <bybell@nc.rr.com>.\n",nam);
@@ -179,16 +185,18 @@ char *lxname=NULL;
 int c;
 int rc;
 int i, j, k;
+int comprehensive = 0;
 
 WAVE_LOCALE_FIX
 
 while (1)
         {
+#ifdef __linux__
         int option_index = 0;
                         
-#ifdef __linux__
         static struct option long_options[] =
                 {
+		{"comprehensive", 0, 0, 'c'},
 		{"dumpfile", 1, 0, 'd'},
 		{"match", 1, 0, 'm'},
 		{"hex", 1, 0, 'x'},
@@ -197,15 +205,19 @@ while (1)
                 {0, 0, 0, 0}  
                 };
                 
-        c = getopt_long (argc, argv, "d:m:x:nh", long_options, &option_index);
+        c = getopt_long (argc, argv, "d:m:x:nch", long_options, &option_index);
 #else
-        c = getopt      (argc, argv, "d:m:x:nh");
+        c = getopt      (argc, argv, "d:m:x:nch");
 #endif
                         
         if (c == -1) break;     /* no more args */
                         
         switch (c)
                 {
+		case 'c':
+			comprehensive = 1;
+			break;
+
 		case 'n':
 			names_only = 1;
 			break;
@@ -294,6 +306,11 @@ if (optind < argc)
                 }
         }
                         
+if(!names_only && comprehensive)
+	{
+	killed_value = 0;
+	}
+
 if(!lxname)
         {
         print_help(argv[0]);
@@ -306,8 +323,17 @@ return(rc);
 }
 
 /*
- * $Id: lxt2miner.c,v 1.2 2008/07/01 18:51:07 gtkwave Exp $
+ * $Id: lxt2miner.c,v 1.5 2009/04/27 21:26:34 gtkwave Exp $
  * $Log: lxt2miner.c,v $
+ * Revision 1.5  2009/04/27 21:26:34  gtkwave
+ * printf format string warning fixes
+ *
+ * Revision 1.4  2009/03/31 18:49:49  gtkwave
+ * removal of warnings under cygwin compile
+ *
+ * Revision 1.3  2009/03/09 23:29:12  gtkwave
+ * fixed memory access violation and added comprehensive option.
+ *
  * Revision 1.2  2008/07/01 18:51:07  gtkwave
  * compiler warning fixes for amd64
  *
