@@ -50,8 +50,12 @@ typedef guint64         UTimeType;
 #ifndef _MSC_VER
 #define LLDescriptor(x) x##LL
 #define ULLDescriptor(x) x##ULL
+#ifndef __MINGW32__
 #define TTFormat "%lld"
 #else
+#define TTFormat "%I64d"
+#endif
+#else
 #define LLDescriptor(x) x##i64
 #define ULLDescriptor(x) x##i64
 #define TTFormat "%I64d"
@@ -106,8 +110,11 @@ TimeType atoi_64(char *str);
 #endif
 
 /*
- * $Id: v2l_debug.h,v 1.1.1.1 2007/05/30 04:28:19 gtkwave Exp $
+ * $Id: v2l_debug.h,v 1.2 2009/04/20 18:48:12 gtkwave Exp $
  * $Log: v2l_debug.h,v $
+ * Revision 1.2  2009/04/20 18:48:12  gtkwave
+ * mingw fixes
+ *
  * Revision 1.1.1.1  2007/05/30 04:28:19  gtkwave
  * Imported sources
  *
