@@ -1947,7 +1947,7 @@ while (1)
 			break;
 
 		case 'b':
-			sscanf(optarg, "%lld", &opt_break_size);
+			sscanf(optarg, "%llu", &opt_break_size);
 			errno = 0;
 			break;
 
@@ -2010,8 +2010,11 @@ return(0);
 }
 
 /*
- * $Id: vcd2lxt2.c,v 1.9 2010/02/22 21:13:37 gtkwave Exp $
+ * $Id: vcd2lxt2.c,v 1.10 2010/07/16 16:19:10 gtkwave Exp $
  * $Log: vcd2lxt2.c,v $
+ * Revision 1.10  2010/07/16 16:19:10  gtkwave
+ * warning fixes
+ *
  * Revision 1.9  2010/02/22 21:13:37  gtkwave
  * added "realtime" VCD variable
  *
