@@ -1951,7 +1951,7 @@ while (1)
 			break;
 
 		case 'b':
-			sscanf(optarg, "%lld", &opt_break_size);
+			sscanf(optarg, "%llu", &opt_break_size);
 			errno = 0;
 			break;
 
@@ -2017,8 +2017,11 @@ return(0);
 }
 
 /*
- * $Id: vcd2vzt.c,v 1.11 2010/02/22 21:13:37 gtkwave Exp $
+ * $Id: vcd2vzt.c,v 1.12 2010/07/16 16:19:10 gtkwave Exp $
  * $Log: vcd2vzt.c,v $
+ * Revision 1.12  2010/07/16 16:19:10  gtkwave
+ * warning fixes
+ *
  * Revision 1.11  2010/02/22 21:13:37  gtkwave
  * added "realtime" VCD variable
  *
