@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2007 Tony Bybell.
+ * Copyright (c) 2003-2009 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -33,6 +33,7 @@
 
 static int flat_earth = 0;
 static int vectorize = 0;
+static int notruncate = 0;
 
 extern void free_hier(void);
 extern char *output_hier(char *name);
@@ -44,22 +45,51 @@ extern char *output_hier(char *name);
 static char *vcdid(int value)
 {
 static char buf[16];
+char *pnt = buf;
+int i, vmod;
+
+value++;
+for(i=0;;i++)
+        {
+        if((vmod = (value % 94)))
+                {
+                *(pnt++) = (char)(vmod + 32);
+                }   
+                else
+                {
+                *(pnt++) = '~'; value -= 94;
+                }
+        value = value / 94;  
+        if(!value) { break; }
+        }
+
+*pnt = 0;   
+return(buf);
+}
+
+/*
+static char *vcdid(int value)
+{
+static char buf[16];
 int i;
 
 for(i=0;i<15;i++)
         {
-        buf[i]=(char)((value%94)+33); /* for range 33..126 */
+        buf[i]=(char)((value%94)+33);
         value=value/94;
         if(!value) {buf[i+1]=0; break;}
         }
 
 return(buf);
 }
+*/
 
 static char *vcd_truncate_bitvec(char *s)
 {
 char l, r;
 
+if(notruncate) return(s);
+
 r=*s;
 if(r=='1')
         {
@@ -230,7 +260,7 @@ if(lt)
                        		{
                                 if(g->msb!=-1)
                                 	{
-                                        printf("$var wire 1 %s %s[%d] $end\n", vcdid(newindx), netname, g->msb);
+                                        printf("$var wire 1 %s %s ["VZT_RD_LD"] $end\n", vcdid(newindx), netname, g->msb);
                                         }
                                         else
                                         {
@@ -241,11 +271,11 @@ if(lt)
                                 {
 				if(!(g->flags & VZT_RD_SYM_F_INTEGER))
 					{
-	                                if(g->len) printf("$var wire %d %s %s[%d:%d] $end\n", g->len, vcdid(newindx), netname, g->msb, g->lsb);
+	                                if(g->len) printf("$var wire "VZT_RD_LD" %s %s ["VZT_RD_LD":"VZT_RD_LD"] $end\n", g->len, vcdid(newindx), netname, g->msb, g->lsb);
 					}
 					else
 					{
-	                                printf("$var integer %d %s %s $end\n", g->len, vcdid(newindx), netname);
+	                                printf("$var integer "VZT_RD_LD" %s %s $end\n", g->len, vcdid(newindx), netname);
 					}
                                 }
                         }
@@ -290,15 +320,17 @@ printf(
 "  -v, --vztname=FILE         specify VZT input filename\n"
 "  -f, --flatearth            emit flattened hierarchies\n"
 "  -c, --coalesce             coalesce bitblasted vectors\n"
+"  -n, --notruncate           do not shorten bitvectors\n"
 "  -h, --help                 display this help then exit\n\n"
 "VCD is emitted to stdout.\n\n"
 "Report bugs to <bybell@nc.rr.com>.\n",nam);
 #else
 printf(
 "Usage: %s [OPTION]... [VZTFILE]\n\n"
-"  -l                         specify VZT input filename\n"
+"  -v                         specify VZT input filename\n"
 "  -f                         emit flattened hierarchies\n"
 "  -c                         coalesce bitblasted vectors\n"
+"  -n                         do not shorten bitvectors\n"
 "  -h                         display this help then exit\n\n"
 
 "VCD is emitted to stdout.\n\n"
@@ -320,21 +352,22 @@ WAVE_LOCALE_FIX
 
 while (1)
         {
+#ifdef __linux__
         int option_index = 0;
                         
-#ifdef __linux__
         static struct option long_options[] =
                 {
 		{"vztname", 1, 0, 'v'},
 		{"coalesce", 0, 0, 'c'},
 		{"flatearth", 0, 0, 'f'},
+		{"notruncate", 0, 0, 'n'},
                 {"help", 0, 0, 'h'},
                 {0, 0, 0, 0}  
                 };
                 
-        c = getopt_long (argc, argv, "v:cfh", long_options, &option_index);
+        c = getopt_long (argc, argv, "v:cfnh", long_options, &option_index);
 #else
-        c = getopt      (argc, argv, "v:cfh");
+        c = getopt      (argc, argv, "v:cfnh");
 #endif
                         
         if (c == -1) break;     /* no more args */
@@ -350,6 +383,9 @@ while (1)
 		case 'c': vectorize=1;
 			break;
 
+		case 'n': notruncate=1;
+			break;
+
 		case 'f': flat_earth=1;
 			break;
 
@@ -396,8 +432,23 @@ return(rc);
 }
 
 /*
- * $Id: vzt2vcd.c,v 1.3 2008/07/19 23:26:49 gtkwave Exp $
+ * $Id: vzt2vcd.c,v 1.8 2009/06/14 19:26:14 gtkwave Exp $
  * $Log: vzt2vcd.c,v $
+ * Revision 1.8  2009/06/14 19:26:14  gtkwave
+ * fix short description (-l should be -v)
+ *
+ * Revision 1.7  2009/04/30 19:18:41  gtkwave
+ * added space before final brackets in VCD writers
+ *
+ * Revision 1.6  2009/04/27 21:26:34  gtkwave
+ * printf format string warning fixes
+ *
+ * Revision 1.5  2009/04/15 21:39:50  gtkwave
+ * use XL-style identifier sequencing for VCD identifiers
+ *
+ * Revision 1.4  2009/03/31 18:49:49  gtkwave
+ * removal of warnings under cygwin compile
+ *
  * Revision 1.3  2008/07/19 23:26:49  gtkwave
  * fixed buffer overflow in vectorization code
  *
