@@ -35,7 +35,9 @@ extern "C" {
 
 #ifndef _MSC_VER
 #include <unistd.h>
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
+#endif
 #else
 typedef long off_t;
 #include <windows.h>
@@ -79,13 +81,8 @@ typedef uint16_t 		vztint16_t;
 typedef uint32_t		vztint32_t;
 typedef uint64_t	 	vztint64_t;
 #ifndef __MINGW32__
-#if __WORDSIZE == 64
-        #define VZT_RD_LLD "%ld"      
-        #define VZT_RD_LD "%d"      
-#else
-        #define VZT_RD_LLD "%lld"      
-        #define VZT_RD_LD "%ld"      
-#endif
+#define VZT_RD_LLD "%"PRId64      
+#define VZT_RD_LD "%"PRId32      
 #else
 #define VZT_RD_LLD "%I64d"
 #define VZT_RD_LD "%d"
@@ -290,8 +287,14 @@ char *				vzt_rd_value(struct vzt_rd_trace *lt, vztint64_t simtime, vztint32_t f
 #endif
 
 /*
- * $Id: vzt_read.h,v 1.5 2010/02/18 17:27:07 gtkwave Exp $
+ * $Id: vzt_read.h,v 1.7 2010/05/27 06:49:31 gtkwave Exp $
  * $Log: vzt_read.h,v $
+ * Revision 1.7  2010/05/27 06:49:31  gtkwave
+ * printf warnings fixes
+ *
+ * Revision 1.6  2010/04/27 23:10:56  gtkwave
+ * made inttype.h inclusion conditional
+ *
  * Revision 1.5  2010/02/18 17:27:07  gtkwave
  * extern "C" headers / version bump
  *
