@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-7 Tony Bybell.
+ * Copyright (c) 2003-2009 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -34,6 +34,7 @@ static char *match = NULL;
 static int matchlen = 0;
 static int names_only = 0;
 static char *killed_list = NULL;
+char killed_value = 1;
 
 extern void free_hier(void);
 extern char *output_hier(char *name);
@@ -69,17 +70,17 @@ if(g->len >= matchlen)
 	{
 	if(!killed_list[*pnt_facidx])
 		{
-		if(strstr(*pnt_value, match))
+		if((!match) || (strstr(*pnt_value, match)))
 			{
 			if(g->len > 1)
 				{
 				if(!names_only)
 					{
-					printf("#"VZT_RD_LLD" %s[%d:%d] %s\n", *pnt_time, vzt_rd_get_facname(*lt, *pnt_facidx), g->msb, g->lsb, *pnt_value);
+					printf("#"VZT_RD_LLD" %s["VZT_RD_LD":"VZT_RD_LD"] %s\n", *pnt_time, vzt_rd_get_facname(*lt, *pnt_facidx), g->msb, g->lsb, *pnt_value);
 					}
 					else
 					{
-					printf("%s[%d:%d]\n", vzt_rd_get_facname(*lt, *pnt_facidx), g->msb, g->lsb);
+					printf("%s["VZT_RD_LD":"VZT_RD_LD"]\n", vzt_rd_get_facname(*lt, *pnt_facidx), g->msb, g->lsb);
 					}
 				}
 				else
@@ -99,16 +100,19 @@ if(g->len >= matchlen)
 					{
 					if(!names_only)
 						{
-						printf("#"VZT_RD_LLD" %s[%d] %s\n", *pnt_time, vzt_rd_get_facname(*lt, *pnt_facidx), g->msb, *pnt_value);
+						printf("#"VZT_RD_LLD" %s["VZT_RD_LD"] %s\n", *pnt_time, vzt_rd_get_facname(*lt, *pnt_facidx), g->msb, *pnt_value);
 						}
 						else
 						{
-						printf("%s[%d]\n", vzt_rd_get_facname(*lt, *pnt_facidx), g->msb);
+						printf("%s["VZT_RD_LD"]\n", vzt_rd_get_facname(*lt, *pnt_facidx), g->msb);
 						}
 					}
 				}
-			vzt_rd_clr_fac_process_mask(*lt, *pnt_facidx);
-			killed_list[*pnt_facidx] = 1;
+			if(killed_value)
+				{
+				vzt_rd_clr_fac_process_mask(*lt, *pnt_facidx);
+				killed_list[*pnt_facidx] = 1;
+				}
 			}
 		}
 	}
@@ -155,6 +159,7 @@ printf(
 "  -m, --match                bitwise match value\n"
 "  -x, --hex                  hex match value\n"
 "  -n, --namesonly            emit facsnames only (gtkwave savefile)\n"
+"  -c, --comprehensive        do not stop after first match\n"
 "  -h, --help                 display this help then exit\n\n"
 "First occurrence of facnames with times and matching values are emitted to\nstdout.  Using -n generates a gtkwave save file.\n\n"
 "Report bugs to <bybell@nc.rr.com>.\n",nam);
@@ -165,6 +170,7 @@ printf(
 "  -m                         bitwise match value\n"
 "  -x                         hex match value\n"
 "  -n                         emit facsnames only\n"
+"  -c                         do not stop after first match\n"
 "  -h                         display this help then exit (gtkwave savefile)\n\n"
 "First occurrence of facnames with times and matching values are emitted to\nstdout.  Using -n generates a gtkwave save file.\n\n"
 "Report bugs to <bybell@nc.rr.com>.\n",nam);
@@ -181,38 +187,45 @@ char *lxname=NULL;
 int c;
 int rc;
 int i, j, k;
+int comprehensive = 0;
+
 
 WAVE_LOCALE_FIX
 
 while (1)
         {
+#ifdef __linux__
         int option_index = 0;
                         
-#ifdef __linux__
         static struct option long_options[] =
                 {
-		{"vztname", 1, 0, 'v'},
+		{"dumpfile", 1, 0, 'd'},
 		{"match", 1, 0, 'm'},
 		{"hex", 1, 0, 'x'},
 		{"namesonly", 0, 0, 'n'},
+		{"comprehensive", 0, 0, 'c'},
                 {"help", 0, 0, 'h'},
                 {0, 0, 0, 0}  
                 };
                 
-        c = getopt_long (argc, argv, "v:m:x:nh", long_options, &option_index);
+        c = getopt_long (argc, argv, "d:m:x:nch", long_options, &option_index);
 #else
-        c = getopt      (argc, argv, "v:m:x:nh");
+        c = getopt      (argc, argv, "d:m:x:nch");
 #endif
                         
         if (c == -1) break;     /* no more args */
                         
         switch (c)
                 {
+		case 'c':
+			comprehensive = 1;
+			break;
+
 		case 'n':
 			names_only = 1;
 			break;
 
-		case 'v':
+		case 'd':
 			if(lxname) free(lxname);
                         lxname = malloc(strlen(optarg)+1);
                         strcpy(lxname, optarg);
@@ -278,6 +291,11 @@ while (1)
                         break;
                 }
         }
+
+if(!names_only && comprehensive) 
+	{
+	killed_value = 0;
+	}
                         
 if(opt_errors_encountered)
         {
@@ -288,11 +306,12 @@ if (optind < argc)
         {               
         while (optind < argc)
                 {
-                if(!lxname)
+                if(lxname)
                         {
-                        lxname = malloc(strlen(argv[optind])+1);
-                        strcpy(lxname, argv[optind++]);
-                        }
+			free(lxname);
+			}
+                lxname = malloc(strlen(argv[optind])+1);
+                strcpy(lxname, argv[optind++]);
                 }
         }
                         
@@ -308,8 +327,17 @@ return(rc);
 }
 
 /*
- * $Id: vztminer.c,v 1.2 2008/07/01 18:51:07 gtkwave Exp $
+ * $Id: vztminer.c,v 1.5 2009/04/27 21:26:34 gtkwave Exp $
  * $Log: vztminer.c,v $
+ * Revision 1.5  2009/04/27 21:26:34  gtkwave
+ * printf format string warning fixes
+ *
+ * Revision 1.4  2009/03/31 18:49:49  gtkwave
+ * removal of warnings under cygwin compile
+ *
+ * Revision 1.3  2009/03/09 23:29:12  gtkwave
+ * fixed memory access violation and added comprehensive option.
+ *
  * Revision 1.2  2008/07/01 18:51:07  gtkwave
  * compiler warning fixes for amd64
  *
