@@ -12,6 +12,9 @@
 
 #include "globals.h"
 
+void create_hier_array(void);
+void free_hier_tree(void);
+
 char *hier_decompress(char *n);
 char *hier_decompress_flagged(char *n, int *was_packed);
 
@@ -22,8 +25,14 @@ enum { HIERPACK_DO_NOT_ADD = 0, HIERPACK_ADD };
 #endif
 
 /*
- * $Id: hierpack.h,v 1.2 2008/07/18 17:29:50 gtkwave Exp $
+ * $Id: hierpack.h,v 1.4 2010/03/01 19:19:50 gtkwave Exp $
  * $Log: hierpack.h,v $
+ * Revision 1.4  2010/03/01 19:19:50  gtkwave
+ * more hier_pfx code movement into hierpack.c
+ *
+ * Revision 1.3  2010/03/01 05:16:26  gtkwave
+ * move compressed hier tree traversal to hierpack
+ *
  * Revision 1.2  2008/07/18 17:29:50  gtkwave
  * adding cvs headers
  *
