@@ -12,7 +12,7 @@
 #ifndef WAVE_LX2RDR_H
 #define WAVE_LX2RDR_H
 
-#ifndef _MSC_VER
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
 #endif
 
@@ -37,8 +37,11 @@ void lx2_import_masked(void);
 #endif
 
 /*
- * $Id: lx2.h,v 1.3 2009/06/07 08:40:44 gtkwave Exp $
+ * $Id: lx2.h,v 1.4 2010/04/27 23:10:56 gtkwave Exp $
  * $Log: lx2.h,v $
+ * Revision 1.4  2010/04/27 23:10:56  gtkwave
+ * made inttype.h inclusion conditional
+ *
  * Revision 1.3  2009/06/07 08:40:44  gtkwave
  * adding FST support
  *
