@@ -2095,8 +2095,8 @@ init_busy();
 
 if(scriptfile)
 	{
-	execute_script(scriptfile);
-	free_2(scriptfile); scriptfile=NULL;
+	execute_script(scriptfile, 1); /* deallocate the name in the script because context might swap out from under us! */
+	scriptfile=NULL;
 	}
 
 #if !defined _MSC_VER
@@ -2654,8 +2654,11 @@ void optimize_vcd_file(void) {
 #endif
 
 /*
- * $Id: main.c,v 1.98 2010/03/31 15:42:47 gtkwave Exp $
+ * $Id: main.c,v 1.99 2010/07/12 20:51:42 gtkwave Exp $
  * $Log: main.c,v $
+ * Revision 1.99  2010/07/12 20:51:42  gtkwave
+ * free to non-malloc'd address fix
+ *
  * Revision 1.98  2010/03/31 15:42:47  gtkwave
  * added preliminary transaction filter support
  *
