@@ -47,9 +47,10 @@ void set_window_xypos(int root_x, int root_y);
 /* stems helper activation */
 int stems_are_active(void);
 void activate_stems_reader(char *stems_name);
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 void kill_stems_browser(void);
 #endif
+void kill_stems_browser_single(void *G);
 
 /* prototype only used in main.c */
 void menu_reload_waveform(GtkWidget *widget, gpointer data);
@@ -59,6 +60,7 @@ void menu_reload_waveform(GtkWidget *widget, gpointer data);
 void optimize_vcd_file(void);
 
 enum FileType {
+  MISSING_FILE,
   LXT_FILE,
   LX2_FILE,
   VZT_FILE,
@@ -69,14 +71,24 @@ enum FileType {
 #ifdef EXTLOAD_SUFFIX
   EXTLOAD_FILE,
 #endif
-  NO_FILE
+  FST_FILE,
+  DUMPLESS_FILE
 };
 
 #endif
 
 /*
- * $Id: main.h,v 1.5 2009/01/27 07:04:31 gtkwave Exp $
+ * $Id: main.h,v 1.8 2009/06/07 08:40:44 gtkwave Exp $
  * $Log: main.h,v $
+ * Revision 1.8  2009/06/07 08:40:44  gtkwave
+ * adding FST support
+ *
+ * Revision 1.7  2009/04/24 20:00:03  gtkwave
+ * rtlbrowse exit kill mods
+ *
+ * Revision 1.6  2009/03/26 20:57:41  gtkwave
+ * added MISSING_FILE support for bringing up gtkwave without a dumpfile
+ *
  * Revision 1.5  2009/01/27 07:04:31  gtkwave
  * added extload external process loader capability
  *
