@@ -34,7 +34,7 @@ void get_main_menu (GtkWidget *, GtkWidget **menubar);
 void menu_set_sensitive(void);
 int file_quit_cmd_callback (GtkWidget *widget, gpointer data);
 int set_wave_menu_accelerator(char *str);
-int execute_script(char *name);
+int execute_script(char *name, int dealloc_name);
 char *append_array_row(nptr n);
 
 struct stringchain_t
@@ -351,8 +351,11 @@ bvptr combine_traces(int direction, Trptr single_trace_only);
 #endif
 
 /*
- * $Id: menu.h,v 1.39 2010/07/01 23:02:41 gtkwave Exp $
+ * $Id: menu.h,v 1.40 2010/07/12 20:51:42 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.40  2010/07/12 20:51:42  gtkwave
+ * free to non-malloc'd address fix
+ *
  * Revision 1.39  2010/07/01 23:02:41  gtkwave
  * header file cleanup
  *
