@@ -60,16 +60,20 @@ else if((flags & TR_ANALOG_INTERPOLATED) != 0) { ch[pos++] = 'I'; }
 if((flags & TR_REAL) != 0) { ch[pos++] = 'R'; }
 
 /* [7] */
+if((flags & TR_REAL2BITS) != 0) { ch[pos++] = 'r'; }
+
+/* [8] */
 if((flags & TR_ZEROFILL) != 0) { ch[pos++] = '0'; }
 else
 if((flags & TR_ONEFILL) != 0) { ch[pos++] = '1'; }
 
-/* [8] */
-if((flags & TR_BINGRAY) != 0) { ch[pos++] = 'G'; }
 /* [9] */
-if((flags & TR_GRAYBIN) != 0) { ch[pos++] = 'g'; }
+if((flags & TR_BINGRAY) != 0) { ch[pos++] = 'G'; }
 
 /* [10]  (at worst case this needs 11 characters) */
+if((flags & TR_GRAYBIN) != 0) { ch[pos++] = 'g'; }
+
+/* [11]  (at worst case this needs 12 characters) */
 ch[pos] = 0;
 
 return(pos);
@@ -95,7 +99,7 @@ if(t->name)
 			char *str;
 			vptr v;
 
-                        v=bsearch_vector(t->n.vec,tim);
+                        v=bsearch_vector(t->n.vec,tim - t->shift);
                         str=convert_ascii(t,v);
 			if(str)
 				{
@@ -113,7 +117,7 @@ if(t->name)
 			{
 			char *str;
 			hptr h_ptr;
-			if((h_ptr=bsearch_node(t->n.nd,tim)))
+			if((h_ptr=bsearch_node(t->n.nd,tim - t->shift)))
 				{
 				if(!t->n.nd->extvals)
 					{
@@ -141,7 +145,7 @@ if(t->name)
 						{
 						if(!(h_ptr->flags&HIST_STRING))
 							{
-							str=convert_ascii_real((double *)h_ptr->v.h_vector);
+							str=convert_ascii_real(t, (double *)h_ptr->v.h_vector);
 							}
 							else
 							{
@@ -251,7 +255,7 @@ int num_info_rows = 2;
 char *flagged_name = NULL;
 char *alternate_name = NULL;
 int fh;
-char flag_string[11];
+char flag_string[65];
 
 if(GLOBALS->disable_mouseover)
 	{
@@ -396,8 +400,14 @@ if(flagged_name) { free_2(flagged_name); }
 }
 
 /*
- * $Id: mouseover.c,v 1.13 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: mouseover.c,v 1.15 2010/04/01 03:10:58 gtkwave Exp $
  * $Log: mouseover.c,v $
+ * Revision 1.15  2010/04/01 03:10:58  gtkwave
+ * time warp fixes
+ *
+ * Revision 1.14  2010/03/24 23:05:10  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.13  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
