@@ -35,7 +35,7 @@ if(!(t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
 	{
 	if(t->vector==TRUE)
 		{
-		s = strdup_2(t->n.vec->name);
+		s = strdup_2(t->n.vec->bvname);
 		}
 		else 
 		{
@@ -88,16 +88,19 @@ else if((flags & TR_ANALOG_INTERPOLATED) != 0) { ch[pos++] = 'I'; }
 if((flags & TR_REAL) != 0) { ch[pos++] = 'R'; }
 
 /* [7] */
+if((flags & TR_REAL2BITS) != 0) { ch[pos++] = 'r'; }
+
+/* [8] */
 if((flags & TR_ZEROFILL) != 0) { ch[pos++] = '0'; }
 else
 if((flags & TR_ONEFILL) != 0) { ch[pos++] = '1'; }
 
-/* [8] */
-if((flags & TR_BINGRAY) != 0) { ch[pos++] = 'G'; }
 /* [9] */
+if((flags & TR_BINGRAY) != 0) { ch[pos++] = 'G'; }
+/* [10] */
 if((flags & TR_GRAYBIN) != 0) { ch[pos++] = 'g'; }
 
-/* [10]  (at worst case this front part needs 11 characters) */
+/* [11]  (at worst case this front part needs 12 characters) */
 ch[pos] = 0;
 
 if(!t->vector)
@@ -140,7 +143,7 @@ if(tname)
 			char *str;
 			vptr v;
 
-                        v=bsearch_vector(t->n.vec,tim);
+                        v=bsearch_vector(t->n.vec,tim - t->shift);
                         str=convert_ascii(t,v);
 			if(str)
 				{
@@ -158,7 +161,7 @@ if(tname)
 			{
 			char *str;
 			hptr h_ptr;
-			if((h_ptr=bsearch_node(t->n.nd,tim)))
+			if((h_ptr=bsearch_node(t->n.nd,tim - t->shift)))
 				{
 				if(!t->n.nd->extvals)
 					{
@@ -186,7 +189,7 @@ if(tname)
 						{
 						if(!(h_ptr->flags&HIST_STRING))
 							{
-							str=convert_ascii_real((double *)h_ptr->v.h_vector);
+							str=convert_ascii_real(t, (double *)h_ptr->v.h_vector);
 							}
 							else
 							{
@@ -443,8 +446,17 @@ if(tname) { free_2(tname); }
 }
 
 /*
- * $Id: mouseover_sigs.c,v 1.7 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: mouseover_sigs.c,v 1.10 2010/04/04 19:09:57 gtkwave Exp $
  * $Log: mouseover_sigs.c,v $
+ * Revision 1.10  2010/04/04 19:09:57  gtkwave
+ * rename name->bvname in struct BitVector for easier grep tracking
+ *
+ * Revision 1.9  2010/04/01 03:10:58  gtkwave
+ * time warp fixes
+ *
+ * Revision 1.8  2010/03/24 23:05:10  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.7  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
