@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2005.
+ * Copyright (c) Tony Bybell 2005-2009
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,14 +29,17 @@ pid_t pid;
 };
 
 
-struct pipe_ctx *pipeio_create(char *execappname);
+struct pipe_ctx *pipeio_create(char *execappname, char *arg);
 void pipeio_destroy(struct pipe_ctx *p);
         
 #endif
 
 /*
- * $Id: pipeio.h,v 1.2 2007/08/26 21:35:43 gtkwave Exp $
+ * $Id: pipeio.h,v 1.3 2009/09/14 03:00:08 gtkwave Exp $
  * $Log: pipeio.h,v $
+ * Revision 1.3  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
  * Revision 1.2  2007/08/26 21:35:43  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
