@@ -2955,8 +2955,7 @@ pr_RenderSig (pr_context * prc, Trptr t, int i)
   {
     int maxwidth = 0;
 
-    if (buf)
-      maxwidth = strlen (buf);
+    maxwidth = strlen (buf);
     if ((t->asciivalue) && (!(t->flags & TR_EXCLUDE)))
       maxwidth += strlen (t->asciivalue);
     if (maxwidth)
@@ -3109,8 +3108,11 @@ print_mif_image (FILE * wave, gdouble px, gdouble py)
 }
 
 /*
- * $Id: print.c,v 1.36 2010/04/14 18:45:37 gtkwave Exp $
+ * $Id: print.c,v 1.37 2010/07/16 16:12:38 gtkwave Exp $
  * $Log: print.c,v $
+ * Revision 1.37  2010/07/16 16:12:38  gtkwave
+ * pedantic warning fixes
+ *
  * Revision 1.36  2010/04/14 18:45:37  gtkwave
  * allow data values for secondary transaction traces
  *
