@@ -82,6 +82,7 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 /*
  * this is likely obsolete
  */
+#if 0
 static void remove_proc_filter(int which, int regen)
 {
 if(GLOBALS->proc_filter[which])
@@ -95,7 +96,7 @@ if(GLOBALS->proc_filter[which])
 	        }
 	}
 }
-
+#endif
 
 static void load_proc_filter(int which, char *name)
 {
@@ -447,8 +448,11 @@ if(GLOBALS->num_proc_filters < PROC_FILTER_MAX)
 #endif
 
 /*
- * $Id: ptranslate.c,v 1.11 2010/04/15 18:39:34 gtkwave Exp $
+ * $Id: ptranslate.c,v 1.12 2010/06/23 05:45:34 gtkwave Exp $
  * $Log: ptranslate.c,v $
+ * Revision 1.12  2010/06/23 05:45:34  gtkwave
+ * warnings fixes
+ *
  * Revision 1.11  2010/04/15 18:39:34  gtkwave
  * remove invocations of pipeio_destroy where unnecessary
  *
