@@ -18,7 +18,7 @@
 #include "fgetdynamic.h"
 #include "debug.h"
 
-#define PROC_FILTER_MAX 20
+#define PROC_FILTER_MAX (128)
 
 
 void ptrans_searchbox(char *title);
@@ -30,8 +30,11 @@ void remove_all_proc_filters(void);
 #endif
 
 /*
- * $Id: ptranslate.h,v 1.2 2007/08/26 21:35:43 gtkwave Exp $
+ * $Id: ptranslate.h,v 1.3 2010/03/30 18:33:27 gtkwave Exp $
  * $Log: ptranslate.h,v $
+ * Revision 1.3  2010/03/30 18:33:27  gtkwave
+ * fixed cut and paste errors from file to proc
+ *
  * Revision 1.2  2007/08/26 21:35:43  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
