@@ -440,6 +440,13 @@ GLOBALS->splash_disable=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_strace_repeat_count(char *str)
+{
+DEBUG(printf("f_strace_repeat_count(\"%s\")\n",str));
+GLOBALS->strace_repeat_count=atoi_64(str);
+return(0);
+}
+
 int f_use_big_fonts(char *str)
 {
 DEBUG(printf("f_use_big_fonts(\"%s\")\n",str));
@@ -761,6 +768,7 @@ static struct rc_entry rcitems[]=
 { "splash_disable", f_splash_disable },
 { "sst_dynamic_filter", f_sst_dynamic_filter },  
 { "sst_expanded", f_sst_expanded },
+{ "strace_repeat_count", f_strace_repeat_count },
 { "use_big_fonts", f_use_big_fonts },
 { "use_frequency_display", f_use_frequency_display },
 { "use_full_precision", f_use_full_precision },
@@ -957,8 +965,11 @@ return;
 }
 
 /*
- * $Id: rc.c,v 1.24 2010/05/06 15:57:52 gtkwave Exp $
+ * $Id: rc.c,v 1.25 2010/06/13 20:38:00 gtkwave Exp $
  * $Log: rc.c,v $
+ * Revision 1.25  2010/06/13 20:38:00  gtkwave
+ * added strace repeat count
+ *
  * Revision 1.24  2010/05/06 15:57:52  gtkwave
  * enable_fast_exit now is enabled by default
  *
