@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2006
+ * Copyright (c) Tony Bybell 1999-2009
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
 #include <errno.h>
 
 static char *render_targets[]=
-        {"PS", "MIF"};
+        {"PDF", "PS", "MIF"};
 
 static char *page_size[]=
         {"Letter (8.5\" x 11\")", "A4 (11.68\" x 8.26\")", "Legal (14\" x 8.5\")", "Letter Prop (6.57\" x 8.5\")", "A4 Prop (8.26\" x 5.84\")"};
@@ -34,7 +34,7 @@ static void render_clicked(GtkWidget *widget, gpointer which)
 {
 int i;
 
-for(i=0;i<2;i++) GLOBALS->target_mutex_renderopt_c_1[i]=0;
+for(i=0;i<3;i++) GLOBALS->target_mutex_renderopt_c_1[i]=0;
 
 i = (int)((long)which);
 GLOBALS->target_mutex_renderopt_c_1[i] = 1; /* mark our choice */
@@ -58,7 +58,7 @@ static void rendertype_clicked(GtkWidget *widget, gpointer which)
 {
 int i;
 
-for(i=0;i<2;i++) GLOBALS->render_mutex_renderopt_c_1[i]=0;
+for(i=0;i<3;i++) GLOBALS->render_mutex_renderopt_c_1[i]=0;
 
 i = (int)((long)which);
 GLOBALS->render_mutex_renderopt_c_1[i] = 1; /* mark our choice */
@@ -90,6 +90,66 @@ if(GLOBALS->filesel_ok)
         }  
 }
 
+static void
+pdf_print_cleanup(GtkWidget *widget, gpointer data)
+{
+FILE *wave;
+FILE *wave2;
+
+if(GLOBALS->filesel_ok)
+        {
+        DEBUG(printf("PDF Print Fini: %s\n", *fileselbox_text));
+                
+        if(!(wave=fopen(*GLOBALS->fileselbox_text,"wb")))
+                {
+                fprintf(stderr, "Error opening PDF output file '%s' for writing.\n",*GLOBALS->fileselbox_text);
+                perror("Why");
+                errno=0;
+                }
+                else
+                {
+		int len = strlen(*GLOBALS->fileselbox_text) ;
+		char *zname = malloc_2(len + 4);
+		strcpy(zname, *GLOBALS->fileselbox_text);
+		strcpy(zname+len, ".ps");
+
+		if(!(wave2=fopen(zname,"wb")))		
+			{
+	                fprintf(stderr, "Error opening PS output tempfile '%s' for writing.\n",zname);
+	                perror("Why");
+			fclose(wave);
+			unlink(*GLOBALS->fileselbox_text);			
+	                errno=0;
+			}
+			else
+			{
+			char *sysname = malloc_2(6 + 1 + len + 3 + 1 + len + 1);
+			int rc;	
+
+			sprintf(sysname, "ps2pdf"	/* 6 */
+					 " "		/* 1 */
+					 "%s"		/* len + 3 */
+					 " "		/* 1 */
+					 "%s"		/* len */
+					 , zname, *GLOBALS->fileselbox_text);
+	                print_ps_image(wave2,px[GLOBALS->page_size_type_renderopt_c_1],py[GLOBALS->page_size_type_renderopt_c_1]);
+	                fclose(wave2);
+			fclose(wave);
+			rc = system(sysname);
+			if(rc)
+				{
+				printf("GTKWAVE | ERROR: rc for '%s' = %d\n", sysname, rc);
+				unlink(*GLOBALS->fileselbox_text);
+				}
+			free_2(sysname);
+			unlink(zname);
+			}
+
+		free_2(zname);
+                }
+        }  
+}
+
 static void
 mif_print_cleanup(GtkWidget *widget, gpointer data)
 {
@@ -118,12 +178,18 @@ static void ok_callback(void)
 {
 GLOBALS->ps_fullpage=GLOBALS->render_mutex_renderopt_c_1[0];
 if(GLOBALS->target_mutex_renderopt_c_1[0])
+	{
+	fileselbox("Print To PDF File",&GLOBALS->filesel_print_pdf_renderopt_c_1,GTK_SIGNAL_FUNC(pdf_print_cleanup), GTK_SIGNAL_FUNC(NULL), "*.pdf", 1);
+	}
+else
+if(GLOBALS->target_mutex_renderopt_c_1[1])
 	{
 	fileselbox("Print To PS File",&GLOBALS->filesel_print_ps_renderopt_c_1,GTK_SIGNAL_FUNC(ps_print_cleanup), GTK_SIGNAL_FUNC(NULL), "*.ps", 1);
 	}
-	else
+else
+/* if(GLOBALS->target_mutex_renderopt_c_1[2]) */
 	{
-	fileselbox("Print To MIF File (experimental)",&GLOBALS->filesel_print_mif_renderopt_c_1,GTK_SIGNAL_FUNC(mif_print_cleanup), GTK_SIGNAL_FUNC(NULL), "*.fm", 1);
+	fileselbox("Print To MIF File",&GLOBALS->filesel_print_mif_renderopt_c_1,GTK_SIGNAL_FUNC(mif_print_cleanup), GTK_SIGNAL_FUNC(NULL), "*.fm", 1);
 	}
 }
 
@@ -143,25 +209,25 @@ void renderbox(char *title)
     GtkWidget *button1, *button2;
     int i;
 
-    if(GLOBALS->script_handle)
+    if(GLOBALS->wave_script_args)
         {
         char *s1 = NULL;
         char *s2 = NULL;
         char *s3 = NULL;
 
-        while((!s1)&&(!feof(GLOBALS->script_handle))) s1 = fgetmalloc_stripspaces(GLOBALS->script_handle);
-        while((!s2)&&(!feof(GLOBALS->script_handle))) s2 = fgetmalloc_stripspaces(GLOBALS->script_handle);
-        while((!s3)&&(!feof(GLOBALS->script_handle))) s3 = fgetmalloc_stripspaces(GLOBALS->script_handle);
+        while((!s1)&&(GLOBALS->wave_script_args->curr)) s1 = wave_script_args_fgetmalloc_stripspaces(GLOBALS->wave_script_args);
+        while((!s2)&&(GLOBALS->wave_script_args->curr)) s2 = wave_script_args_fgetmalloc_stripspaces(GLOBALS->wave_script_args);
+        while((!s3)&&(GLOBALS->wave_script_args->curr)) s3 = wave_script_args_fgetmalloc_stripspaces(GLOBALS->wave_script_args);
 
         if(s1 && s2 && s3)
                 {
 		memset(GLOBALS->target_mutex_renderopt_c_1, 0, 2); GLOBALS->target_mutex_renderopt_c_1[0] = 1; /* PS */
-		for(i=0;i<2;i++)
+		for(i=0;i<3;i++)
 			{
 			if(!strcmp(s1, render_targets[i]))
 				{
 				fprintf(stderr, "GTKWAVE | Print using '%s'\n",  render_targets[i]);
-				memset(GLOBALS->target_mutex_renderopt_c_1, 0, 2); GLOBALS->target_mutex_renderopt_c_1[i] = 1; break;
+				memset(GLOBALS->target_mutex_renderopt_c_1, 0, 3); GLOBALS->target_mutex_renderopt_c_1[i] = 1; break;
 				}
 			}
 
@@ -178,13 +244,13 @@ void renderbox(char *title)
 				}
 			}
 
-		memset(GLOBALS->render_mutex_renderopt_c_1, 0, 2); GLOBALS->render_mutex_renderopt_c_1[0] = 1; /* Full */
+		memset(GLOBALS->render_mutex_renderopt_c_1, 0, 3); GLOBALS->render_mutex_renderopt_c_1[0] = 1; /* Full */
 		for(i=0;i<2;i++)
 			{
 			if(!strcmp(s3, render_type[i]))
 				{
 				fprintf(stderr, "GTKWAVE | Print using '%s'\n",  render_type[i]);
-				memset(GLOBALS->render_mutex_renderopt_c_1, 0, 2); GLOBALS->render_mutex_renderopt_c_1[i] = 1; break;
+				memset(GLOBALS->render_mutex_renderopt_c_1, 0, 3); GLOBALS->render_mutex_renderopt_c_1[i] = 1; break;
 				}
 			}
 
@@ -228,7 +294,7 @@ void renderbox(char *title)
     menu = gtk_menu_new ();
     group=NULL;
 
-    for(i=0;i<2;i++)
+    for(i=0;i<3;i++)
 	{
     	menuitem = gtk_radio_menu_item_new_with_label (group, render_targets[i]);
     	group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menuitem));
@@ -313,8 +379,23 @@ void renderbox(char *title)
 }
 
 /*
- * $Id: renderopt.c,v 1.6 2008/06/11 08:01:53 gtkwave Exp $
+ * $Id: renderopt.c,v 1.11 2009/12/15 23:40:59 gtkwave Exp $
  * $Log: renderopt.c,v $
+ * Revision 1.11  2009/12/15 23:40:59  gtkwave
+ * removed old style scripts; also removed tempfiles for Tcl args
+ *
+ * Revision 1.10  2009/05/21 04:04:10  gtkwave
+ * crash fixes introduced by ps2pdf addition
+ *
+ * Revision 1.9  2009/03/31 18:49:49  gtkwave
+ * removal of warnings under cygwin compile
+ *
+ * Revision 1.8  2009/03/29 02:45:41  gtkwave
+ * added missing savefile name for pdf (from invocation to invocation)
+ *
+ * Revision 1.7  2009/03/29 02:08:36  gtkwave
+ * added support for PDF file generation via ps2pdf
+ *
  * Revision 1.6  2008/06/11 08:01:53  gtkwave
  * gcc 4.3.x compiler warning fixes
  *
@@ -360,4 +441,3 @@ void renderbox(char *title)
  * initial release
  *
  */
-
