@@ -7,6 +7,7 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
 #include <config.h>
 #include "currenttime.h"
 #include "pixmaps.h"
@@ -19,7 +20,7 @@ GtkAdjustment *hadj;
 gfloat inc;
 TimeType ntinc;
 
-if(helpbox_is_active)
+if(GLOBALS->helpbox_is_active)
         {
         help_text_bold("\n\nShift Left");
         help_text(
@@ -33,15 +34,15 @@ if(helpbox_is_active)
         }
 
 
-if(nspx>1.0) inc=nspx; else inc=1.0;
+if(GLOBALS->nspx>1.0) inc=GLOBALS->nspx; else inc=1.0;
 
-hadj=GTK_ADJUSTMENT(wave_hslider);
-if((hadj->value-inc)>tims.first) hadj->value=hadj->value-inc;
-	else hadj->value=tims.first;
+hadj=GTK_ADJUSTMENT(GLOBALS->wave_hslider);
+if((hadj->value-inc)>GLOBALS->tims.first) hadj->value=hadj->value-inc;
+	else hadj->value=GLOBALS->tims.first;
 
 ntinc=(TimeType)inc;
-if((tims.start-ntinc)>tims.first) tims.timecache=tims.start-ntinc;
-	else tims.timecache=tims.first;
+if((GLOBALS->tims.start-ntinc)>GLOBALS->tims.first) GLOBALS->tims.timecache=GLOBALS->tims.start-ntinc;
+	else GLOBALS->tims.timecache=GLOBALS->tims.first;
 
 time_update();
 
@@ -55,7 +56,7 @@ GtkAdjustment *hadj;
 gfloat inc;
 TimeType ntinc, pageinc;
 
-if(helpbox_is_active)
+if(GLOBALS->helpbox_is_active)
         {
         help_text_bold("\n\nShift Right");
         help_text(
@@ -68,20 +69,20 @@ if(helpbox_is_active)
         return;
         }
 
-if(nspx>1.0) inc=nspx; else inc=1.0;
+if(GLOBALS->nspx>1.0) inc=GLOBALS->nspx; else inc=1.0;
 ntinc=(TimeType)inc;
 
-hadj=GTK_ADJUSTMENT(wave_hslider);
-if((hadj->value+inc)<tims.last) hadj->value=hadj->value+inc;
-	else hadj->value=tims.last-inc;
+hadj=GTK_ADJUSTMENT(GLOBALS->wave_hslider);
+if((hadj->value+inc)<GLOBALS->tims.last) hadj->value=hadj->value+inc;
+	else hadj->value=GLOBALS->tims.last-inc;
 
-pageinc=(TimeType)(((gdouble)wavewidth)*nspx);
+pageinc=(TimeType)(((gdouble)GLOBALS->wavewidth)*GLOBALS->nspx);
 
-if((tims.start+ntinc)<(tims.last-pageinc+1)) tims.timecache=tims.start+ntinc;
+if((GLOBALS->tims.start+ntinc)<(GLOBALS->tims.last-pageinc+1)) GLOBALS->tims.timecache=GLOBALS->tims.start+ntinc;
 	else 
 	{
-	tims.timecache=tims.last-pageinc+1;
-	if(tims.timecache<tims.first) tims.timecache=tims.first;
+	GLOBALS->tims.timecache=GLOBALS->tims.last-pageinc+1;
+	if(GLOBALS->tims.timecache<GLOBALS->tims.first) GLOBALS->tims.timecache=GLOBALS->tims.first;
 	}
 
 time_update();
@@ -106,9 +107,9 @@ GtkTooltips *tooltips;
 tooltips=gtk_tooltips_new_2();
 gtk_tooltips_set_delay_2(tooltips,1500);
 
-pixmapwid1=gtk_pixmap_new(larrow_pixmap, larrow_mask);
+pixmapwid1=gtk_pixmap_new(GLOBALS->larrow_pixmap, GLOBALS->larrow_mask);
 gtk_widget_show(pixmapwid1);
-pixmapwid2=gtk_pixmap_new(rarrow_pixmap, rarrow_mask);
+pixmapwid2=gtk_pixmap_new(GLOBALS->rarrow_pixmap, GLOBALS->rarrow_mask);
 gtk_widget_show(pixmapwid2);
    
 /* Create a table to hold the text widget and scrollbars */
@@ -131,8 +132,7 @@ gtk_container_add(GTK_CONTAINER(b1), pixmapwid1);
 gtk_table_attach (GTK_TABLE (table2), b1, 0, 1, 0, 1,
 			GTK_FILL | GTK_EXPAND,
 		      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
-gtk_signal_connect_object (GTK_OBJECT (b1), "clicked",
-              		GTK_SIGNAL_FUNC(service_left_shift), GTK_OBJECT (table2));
+gtk_signal_connect_object (GTK_OBJECT (b1), "clicked", GTK_SIGNAL_FUNC(service_left_shift), GTK_OBJECT (table2));
 gtk_tooltips_set_tip_2(tooltips, b1, "Shift Left 1 Tick", NULL);
 gtk_widget_show(b1);
 
@@ -141,8 +141,7 @@ gtk_container_add(GTK_CONTAINER(b2), pixmapwid2);
 gtk_table_attach (GTK_TABLE (table2), b2, 0, 1, 1, 2,
 		      	GTK_FILL | GTK_EXPAND,
 		      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
-gtk_signal_connect_object (GTK_OBJECT (b2), "clicked",
-               		GTK_SIGNAL_FUNC(service_right_shift), GTK_OBJECT (table2));
+gtk_signal_connect_object (GTK_OBJECT (b2), "clicked", GTK_SIGNAL_FUNC(service_right_shift), GTK_OBJECT (table2));
 gtk_tooltips_set_tip_2(tooltips, b2, "Shift Right 1 Tick", NULL);
 gtk_widget_show(b2);
 
@@ -152,8 +151,30 @@ return(table);
 }
    
 /*
- * $Id: shiftbuttons.c,v 1.2 2007/04/20 02:08:17 gtkwave Exp $
+ * $Id: shiftbuttons.c,v 1.4 2007/09/12 19:24:45 gtkwave Exp $
  * $Log: shiftbuttons.c,v $
+ * Revision 1.4  2007/09/12 19:24:45  gtkwave
+ * more ctx_swap_watchdog updates
+ *
+ * Revision 1.3  2007/09/12 17:26:45  gtkwave
+ * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
+ *
+ * Revision 1.2  2007/08/26 21:35:44  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.3  2007/08/07 03:18:55  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.2  2007/08/06 03:50:48  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:23  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:21  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:17  gtkwave
  * initial release
  *
