@@ -27,7 +27,9 @@
 
 #ifndef _MSC_VER
 #include <unistd.h>
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
+#endif
 #else
 typedef long off_t;
 #include <windows.h>
@@ -123,8 +125,11 @@ void destroy_s_selected(void);
 #endif
 
 /*
- * $Id: symbol.h,v 1.13 2010/03/16 21:01:10 gtkwave Exp $
+ * $Id: symbol.h,v 1.14 2010/04/27 23:10:56 gtkwave Exp $
  * $Log: symbol.h,v $
+ * Revision 1.14  2010/04/27 23:10:56  gtkwave
+ * made inttype.h inclusion conditional
+ *
  * Revision 1.13  2010/03/16 21:01:10  gtkwave
  * remove selected member of struct symbol
  *
