@@ -2621,7 +2621,26 @@ if((GLOBALS->repscript_name) && (!GLOBALS->tcl_running))
 	GLOBALS->tcl_running = 1;
 	tclrc = Tcl_Eval (GLOBALS->interp, tcl_cmd);
 	GLOBALS->tcl_running = 0;
+#if WAVE_TCL_CHECK_VERSION(8,5,0)
+	if(tclrc != TCL_OK) { 
+	  Tcl_Obj *options;
+	  Tcl_Obj *key;
+	  Tcl_Obj *stackTrace;
+
+	  fprintf(stderr, "GTKWAVE | %s\n", 
+		  Tcl_GetStringResult (GLOBALS->interp)); 
+	  options = Tcl_GetReturnOptions(GLOBALS->interp, tclrc);  
+	  key = Tcl_NewStringObj("-errorinfo", -1);
+	  Tcl_IncrRefCount(key);
+	  Tcl_DictObjGet(NULL, options, key, &stackTrace);
+	  Tcl_DecrRefCount(key);
+	  fprintf(stderr, "TCL Stack Trace\n%s\n",
+		  Tcl_GetStringFromObj(stackTrace, NULL)) ;
+	  /* Do something with stackTrace */
+	}
+#else
 	if(tclrc != TCL_OK) { fprintf (stderr, "GTKWAVE | %s\n", Tcl_GetStringResult (GLOBALS->interp)); }
+#endif
 
 	free_2(tcl_cmd);
 	return(TRUE);
@@ -2733,8 +2752,11 @@ void make_tcl_interpreter(char *argv[])
 
 
 /*
- * $Id: tcl_helper.c,v 1.78 2010/04/07 01:50:45 gtkwave Exp $
+ * $Id: tcl_helper.c,v 1.79 2010/07/15 14:27:05 gtkwave Exp $
  * $Log: tcl_helper.c,v $
+ * Revision 1.79  2010/07/15 14:27:05  gtkwave
+ * repscript timer fix to print stack trace
+ *
  * Revision 1.78  2010/04/07 01:50:45  gtkwave
  * improved name handling for bvname, add $next transaction operation
  *
