@@ -18,6 +18,13 @@
 #include <tk.h>
 #include "debug.h"
 
+#define WAVE_TCL_CHECK_VERSION(major,minor,micro)    \
+    (TCL_MAJOR_VERSION > (major) || \
+     (TCL_MAJOR_VERSION == (major) && TCL_MINOR_VERSION > (minor)) || \
+     (TCL_MAJOR_VERSION == (major) && TCL_MINOR_VERSION == (minor) && \
+      TCL_RELEASE_SERIAL >= (micro)))
+
+
 typedef struct
         {
         const char *cmdstr;
@@ -96,8 +103,11 @@ void set_globals_interp(char *me, int install_tk);
 #endif
 
 /* 
- * $Id: tcl_helper.h,v 1.23 2009/12/15 23:40:59 gtkwave Exp $
+ * $Id: tcl_helper.h,v 1.24 2010/07/15 14:27:05 gtkwave Exp $
  * $Log: tcl_helper.h,v $
+ * Revision 1.24  2010/07/15 14:27:05  gtkwave
+ * repscript timer fix to print stack trace
+ *
  * Revision 1.23  2009/12/15 23:40:59  gtkwave
  * removed old style scripts; also removed tempfiles for Tcl args
  *
