@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,10 +64,78 @@ for(;;)
 }
 
 
+/*
+ * decorated module add
+ */
+void allocate_and_decorate_module_tree_node(unsigned char ttype, const char *scopename)
+{
+struct tree *t;
+
+if(GLOBALS->treeroot)
+	{
+	if(GLOBALS->mod_tree_parent)
+		{
+		t = GLOBALS->mod_tree_parent->child;
+		while(t)
+			{
+			if(!strcmp(t->name, scopename))
+				{
+				GLOBALS->mod_tree_parent = t;
+				return;
+				}
+			t = t->next;
+			}
+
+		t = calloc_2(1, sizeof(struct tree) + strlen(scopename));
+		strcpy(t->name, scopename);
+		t->kind = ttype;
+		t->which = -1;
+
+		if(GLOBALS->mod_tree_parent->child)
+			{
+			t->next = GLOBALS->mod_tree_parent->child;
+			}					
+		GLOBALS->mod_tree_parent->child = t;
+		GLOBALS->mod_tree_parent = t;
+		}
+		else
+		{
+		t = GLOBALS->treeroot;
+			while(t)
+			{
+			if(!strcmp(t->name, scopename))
+				{
+				GLOBALS->mod_tree_parent = t;
+				return;
+				}
+			t = t->next;
+			}
+
+		t = calloc_2(1, sizeof(struct tree) + strlen(scopename));
+		strcpy(t->name, scopename);
+		t->kind = ttype;
+		t->which = -1;
+
+		t->next = GLOBALS->treeroot;
+		GLOBALS->mod_tree_parent = GLOBALS->treeroot = t;
+		}
+	}
+	else
+	{
+	t = calloc_2(1, sizeof(struct tree) + strlen(scopename));
+	strcpy(t->name, scopename);
+	t->kind = ttype;
+	t->which = -1;
+
+	GLOBALS->mod_tree_parent = GLOBALS->treeroot = t;
+	}
+}
+
+
 /*
  * adds back netnames
  */
-int treegraft(struct tree *t)
+int treegraft(struct tree **t)
 {
 struct tree *tx = GLOBALS->terminals_tchain_tree_c_1;
 struct tree *t2;
@@ -95,8 +163,16 @@ while(tx)
 		}
 		else
 		{
-		tx->next = t->next;
-		t->next = tx;
+		if(*t)
+			{
+			tx->next = (*t)->next;
+			(*t)->next = tx;
+			}
+			else
+			{
+			*t = tx;
+			tx->next = NULL;
+			}
 		}
 
 	tx = t2;
@@ -170,6 +246,7 @@ static GtkCTreeNode *maketree_nodes(GtkCTreeNode *subtree, struct tree *t2, GtkC
 {
 char *tmp, *tmp2, *tmp3;
 gchar *text [1];
+GdkDrawable *pxm, *msk;
 
 if(t2->which!=-1)
 	{
@@ -228,8 +305,33 @@ switch(mode)
 		break;
 
 	default:
+		switch(t2->kind)
+			{
+   			case TREE_VCD_ST_MODULE:	pxm = GLOBALS->hiericon_module_pixmap; msk = GLOBALS->hiericon_module_mask; break;
+   			case TREE_VCD_ST_TASK:		pxm = GLOBALS->hiericon_task_pixmap; msk = GLOBALS->hiericon_task_mask; break;
+   			case TREE_VCD_ST_FUNCTION:	pxm = GLOBALS->hiericon_function_pixmap; msk = GLOBALS->hiericon_function_mask; break;
+   			case TREE_VCD_ST_BEGIN:		pxm = GLOBALS->hiericon_begin_pixmap; msk = GLOBALS->hiericon_begin_mask; break;
+   			case TREE_VCD_ST_FORK:		pxm = GLOBALS->hiericon_fork_pixmap; msk = GLOBALS->hiericon_fork_mask; break;
+
+			case TREE_VHDL_ST_DESIGN:	pxm = GLOBALS->hiericon_design_pixmap; msk = GLOBALS->hiericon_design_mask; break;
+			case TREE_VHDL_ST_BLOCK:	pxm = GLOBALS->hiericon_block_pixmap; msk = GLOBALS->hiericon_block_mask; break;
+			case TREE_VHDL_ST_GENIF:	pxm = GLOBALS->hiericon_generateif_pixmap; msk = GLOBALS->hiericon_generateif_mask; break;
+			case TREE_VHDL_ST_GENFOR:	pxm = GLOBALS->hiericon_generatefor_pixmap; msk = GLOBALS->hiericon_generatefor_mask; break;
+			case TREE_VHDL_ST_INSTANCE:	pxm = GLOBALS->hiericon_instance_pixmap; msk = GLOBALS->hiericon_instance_mask; break;
+			case TREE_VHDL_ST_PACKAGE:	pxm = GLOBALS->hiericon_package_pixmap; msk = GLOBALS->hiericon_package_mask; break;
+
+			case TREE_VHDL_ST_SIGNAL:	pxm = GLOBALS->hiericon_signal_pixmap; msk = GLOBALS->hiericon_signal_mask; break;
+			case TREE_VHDL_ST_PORTIN:	pxm = GLOBALS->hiericon_portin_pixmap; msk = GLOBALS->hiericon_portin_mask; break;
+			case TREE_VHDL_ST_PORTOUT:	pxm = GLOBALS->hiericon_portout_pixmap; msk = GLOBALS->hiericon_portout_mask; break;
+			case TREE_VHDL_ST_PORTINOUT:	pxm = GLOBALS->hiericon_portinout_pixmap; msk = GLOBALS->hiericon_portinout_mask; break;
+			case TREE_VHDL_ST_BUFFER:	pxm = GLOBALS->hiericon_buffer_pixmap; msk = GLOBALS->hiericon_buffer_mask; break;
+			case TREE_VHDL_ST_LINKAGE:	pxm = GLOBALS->hiericon_linkage_pixmap; msk = GLOBALS->hiericon_linkage_mask; break;
+
+			default:			pxm = msk = NULL; break;
+			}
+
 	        sibling = gtk_ctree_insert_node (GLOBALS->ctree_main, subtree, sibling, text, 3,
-               	                       NULL, NULL, NULL, NULL,
+               	                       pxm, msk, pxm, msk,
                	                       (mode==MAKETREE_LEAF), FALSE);
 		gtk_ctree_node_set_row_data(GLOBALS->ctree_main, sibling, t2);
 		break;
@@ -383,7 +485,7 @@ GLOBALS->facs2_tree_c_1 = NULL;
 void build_tree_from_name(const char *s, int which)
 {
 struct tree *t, *nt;
-struct tree *tchain;
+struct tree *tchain, *tchain_iter;
 struct tree *prevt;
 
 if(s==NULL || !s[0]) return;
@@ -404,7 +506,7 @@ rs:		s=get_module_name(s);
 			continue;
 			}
 
-		tchain = t;
+		tchain = tchain_iter = t;
 		if(s && t)
 			{
 		      	nt = t->next;
@@ -412,11 +514,20 @@ rs:		s=get_module_name(s);
 				{
 				if(nt && !strcmp(nt->name, GLOBALS->module_tree_c_1))
 					{
+					/* move to front to speed up next compare if in same hier during build */
+					if(prevt)
+						{
+						tchain_iter->next = nt->next;
+						nt->next = tchain;
+						prevt->child = nt;
+						}
+
 					prevt = nt;
 					t = nt->child;
 					goto rs;
 					}
 
+				tchain_iter = nt;
 				nt = nt->next;
 				}
 			}
@@ -599,8 +710,23 @@ if(!GLOBALS->hier_grouping)
 #endif
 
 /*
- * $Id: tree.c,v 1.3 2008/12/26 20:47:59 gtkwave Exp $
+ * $Id: tree.c,v 1.8 2009/07/02 18:50:47 gtkwave Exp $
  * $Log: tree.c,v $
+ * Revision 1.8  2009/07/02 18:50:47  gtkwave
+ * decorate VCD module trees with type info, add move to front to buildname
+ *
+ * Revision 1.7  2009/07/01 21:58:32  gtkwave
+ * more GHW module type adds for icons in hierarchy window
+ *
+ * Revision 1.6  2009/07/01 18:22:35  gtkwave
+ * added VHDL (GHW) instance types as icons
+ *
+ * Revision 1.5  2009/07/01 16:47:47  gtkwave
+ * move decorated module alloc routine to tree.c
+ *
+ * Revision 1.4  2009/07/01 07:39:12  gtkwave
+ * decorating hierarchy tree with module type info
+ *
  * Revision 1.3  2008/12/26 20:47:59  gtkwave
  * fix for stack overflow crash on dumpfiles with very many signals
  *
