@@ -648,11 +648,32 @@ for(;;)
 	{
 	tok=get_token();
 	if((tok==T_END)||(tok==T_EOF)) break;
-	if(hdr)DEBUG(fprintf(stderr," %s",yytext));
+	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_c_1));
 	}
 if(hdr) DEBUG(fprintf(stderr,"\n"));
 }
 
+static int version_sync_end(char *hdr)
+{
+int tok;
+int rc = 0;
+
+if(hdr) DEBUG(fprintf(stderr,"%s",hdr));
+for(;;)
+	{
+	tok=get_token();
+	if((tok==T_END)||(tok==T_EOF)) break;
+	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_c_1));
+        if(strstr(GLOBALS->yytext_vcd_c_1, "Icarus"))   /* turn off autocoalesce for Icarus */
+                {
+                GLOBALS->autocoalesce = 0;
+		rc = 1;
+                }
+	}
+if(hdr) DEBUG(fprintf(stderr,"\n"));
+return(rc);
+}
+
 char *build_slisthier(void)
 {
 struct slist *s;
@@ -1035,6 +1056,7 @@ static void vcd_parse(void)
 {
 int tok;
 unsigned char ttype;
+int disable_autocoalesce = 0;
 
 for(;;)
 	{
@@ -1047,7 +1069,7 @@ for(;;)
 			sync_end("DATE:");
 			break;
 		case T_VERSION:
-			sync_end("VERSION:");
+			disable_autocoalesce = version_sync_end("VERSION:");
 			break;
 		case T_TIMESCALE:
 			{
@@ -1298,7 +1320,7 @@ for(;;)
 
                                 if(GLOBALS->pv_vcd_c_1)
                                         { 
-                                        if(!strcmp(GLOBALS->pv_vcd_c_1->name,v->name))
+                                        if(!strcmp(GLOBALS->pv_vcd_c_1->name,v->name) && !disable_autocoalesce && (!strchr(v->name, '\\')))
                                                 {
                                                 GLOBALS->pv_vcd_c_1->chain=v;
                                                 v->root=GLOBALS->rootv_vcd_c_1;
@@ -2596,8 +2618,14 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.32 2010/03/18 17:12:37 gtkwave Exp $
+ * $Id: vcd.c,v 1.34 2010/06/02 03:51:30 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.34  2010/06/02 03:51:30  gtkwave
+ * don't autocoalesce escape identifiers
+ *
+ * Revision 1.33  2010/06/02 03:23:04  gtkwave
+ * disable autocoalesce if Icarus Verilog is detected
+ *
  * Revision 1.32  2010/03/18 17:12:37  gtkwave
  * pedantic warning cleanups
  *
