@@ -643,11 +643,32 @@ for(;;)
 	{
 	tok=get_token();
 	if((tok==T_END)||(tok==T_EOF)) break;
-	if(hdr)DEBUG(fprintf(stderr," %s",yytext));
+	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_partial_c_2));
 	}
 if(hdr) DEBUG(fprintf(stderr,"\n"));
 }
 
+static int version_sync_end(char *hdr)
+{
+int tok;
+int rc = 0;
+
+if(hdr) DEBUG(fprintf(stderr,"%s",hdr));
+for(;;)
+	{
+	tok=get_token();
+	if((tok==T_END)||(tok==T_EOF)) break;
+	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_partial_c_2));
+        if(strstr(GLOBALS->yytext_vcd_partial_c_2, "Icarus"))   /* turn off autocoalesce for Icarus */
+                {
+		GLOBALS->autocoalesce = 0;
+                rc = 1;
+                }
+	}
+if(hdr) DEBUG(fprintf(stderr,"\n"));
+return(rc);
+}
+
 
 static void parse_valuechange(void)
 {
@@ -1003,6 +1024,7 @@ static void vcd_parse(void)
 {
 int tok;
 unsigned char ttype;
+int disable_autocoalesce = 0;
 
 for(;;)
 	{
@@ -1015,7 +1037,7 @@ for(;;)
 			sync_end("DATE:");
 			break;
 		case T_VERSION:
-			sync_end("VERSION:");
+			disable_autocoalesce = version_sync_end("VERSION:");
 			break;
 		case T_TIMESCALE:
 			{
@@ -1264,7 +1286,7 @@ for(;;)
 
                                 if(GLOBALS->pv_vcd_partial_c_2)
                                         { 
-                                        if(!strcmp(GLOBALS->pv_vcd_partial_c_2->name,v->name))
+                                        if(!strcmp(GLOBALS->pv_vcd_partial_c_2->name,v->name) && !disable_autocoalesce && (!strchr(v->name, '\\')))
                                                 {
                                                 GLOBALS->pv_vcd_partial_c_2->chain=v;
                                                 v->root=GLOBALS->rootv_vcd_partial_c_2;
@@ -2351,7 +2373,7 @@ if(t->vector)
 	bptr bts = b->bits;
 	int i;
 
-	for(i=0;i<bts->nbits;i++)
+	for(i=0;i<bts->nnbits;i++)
 		{
 		if(!bts->nodes[i]->harray)
 			{
@@ -2380,7 +2402,7 @@ else if(t->interactive_vector_needs_regeneration)
 	int i;
 	bvptr b2;
 
-	for(i=0;i<bts->nbits;i++)
+	for(i=0;i<bts->nnbits;i++)
 		{
 		if(!bts->nodes[i]->harray)
 			{
@@ -2403,8 +2425,8 @@ else if(t->interactive_vector_needs_regeneration)
 	t->n.vec = b2;
 	b2->bits=bts;
 
-	free_2(b2->name);
-	b2->name = b->name;
+	free_2(b2->bvname);
+	b2->bvname = b->bvname;
 
 	for(i=0;i<b->numregions;i++)
 		{
@@ -2509,8 +2531,20 @@ gtkwave_main_iteration();
 }
 
 /*
- * $Id: vcd_partial.c,v 1.32 2010/03/18 17:12:37 gtkwave Exp $
+ * $Id: vcd_partial.c,v 1.36 2010/06/02 03:51:30 gtkwave Exp $
  * $Log: vcd_partial.c,v $
+ * Revision 1.36  2010/06/02 03:51:30  gtkwave
+ * don't autocoalesce escape identifiers
+ *
+ * Revision 1.35  2010/06/02 03:23:04  gtkwave
+ * disable autocoalesce if Icarus Verilog is detected
+ *
+ * Revision 1.34  2010/04/04 19:09:57  gtkwave
+ * rename name->bvname in struct BitVector for easier grep tracking
+ *
+ * Revision 1.33  2010/03/31 15:42:47  gtkwave
+ * added preliminary transaction filter support
+ *
  * Revision 1.32  2010/03/18 17:12:37  gtkwave
  * pedantic warning cleanups
  *
