@@ -1138,11 +1138,32 @@ for(;;)
 	{
 	tok=get_token();
 	if((tok==T_END)||(tok==T_EOF)) break;
-	if(hdr)DEBUG(fprintf(stderr," %s",yytext));
+	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_recoder_c_3));
 	}
 if(hdr) DEBUG(fprintf(stderr,"\n"));
 }
 
+static int version_sync_end(char *hdr)
+{
+int tok;
+int rc = 0;
+
+if(hdr) DEBUG(fprintf(stderr,"%s",hdr));
+for(;;)
+	{
+	tok=get_token();
+	if((tok==T_END)||(tok==T_EOF)) break;
+	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_recoder_c_3));
+	if(strstr(GLOBALS->yytext_vcd_recoder_c_3, "Icarus"))	/* turn off autocoalesce for Icarus */
+		{
+		GLOBALS->autocoalesce = 0;
+		rc = 1;
+		}
+	}
+if(hdr) DEBUG(fprintf(stderr,"\n"));
+return(rc);
+}
+
 static void parse_valuechange(void)
 {
 struct vcdsymbol *v;
@@ -1357,6 +1378,7 @@ static void vcd_parse(void)
 {
 int tok;
 unsigned char ttype;
+int disable_autocoalesce = 0;
 
 for(;;)
 	{
@@ -1369,7 +1391,7 @@ for(;;)
 			sync_end("DATE:");
 			break;
 		case T_VERSION:
-			sync_end("VERSION:");
+			disable_autocoalesce = version_sync_end("VERSION:");
 			break;
 		case T_TIMESCALE:
 			{
@@ -1618,7 +1640,7 @@ for(;;)
 
                                 if(GLOBALS->pv_vcd_recoder_c_3)
                                         { 
-                                        if(!strcmp(GLOBALS->prev_hier_uncompressed_name,v->name))
+                                        if(!strcmp(GLOBALS->prev_hier_uncompressed_name,v->name) && !disable_autocoalesce && (!strchr(v->name, '\\')))
                                                 {
                                                 GLOBALS->pv_vcd_recoder_c_3->chain=v;
                                                 v->root=GLOBALS->rootv_vcd_recoder_c_3;
@@ -3212,8 +3234,14 @@ np->mv.mvlfac_vlist = NULL;
 }
 
 /*
- * $Id: vcd_recoder.c,v 1.41 2010/03/18 17:12:37 gtkwave Exp $
+ * $Id: vcd_recoder.c,v 1.43 2010/06/02 03:51:30 gtkwave Exp $
  * $Log: vcd_recoder.c,v $
+ * Revision 1.43  2010/06/02 03:51:30  gtkwave
+ * don't autocoalesce escape identifiers
+ *
+ * Revision 1.42  2010/06/02 03:23:04  gtkwave
+ * disable autocoalesce if Icarus Verilog is detected
+ *
  * Revision 1.41  2010/03/18 17:12:37  gtkwave
  * pedantic warning cleanups
  *
